@@ -7,11 +7,13 @@
 #include "kgdeclarativeview.h"
 
 // KF
-#include <KDeclarative/KDeclarative>
 #include <KLocalizedContext>
+#include <KQuickIconProvider>
 // Qt
 #include <QQmlContext>
 
+#if KDEGAMES_BUILD_DEPRECATED_SINCE(7, 5)
+
 class KgDeclarativeViewPrivate
 {
 };
@@ -21,7 +23,9 @@ KgDeclarativeView::KgDeclarativeView(QWidget *parent)
     , d(nullptr) // unused for now, for future expandability
 {
     QQmlEngine *engine = this->engine();
-    KDeclarative::KDeclarative::setupEngine(engine);
+
+    // setup ImageProvider for KIconTheme icons
+    engine->addImageProvider(QStringLiteral("icon"), new KQuickIconProvider);
 
     KLocalizedContext *localizedContextObject = new KLocalizedContext(engine);
     engine->rootContext()->setContextObject(localizedContextObject);
@@ -30,3 +34,5 @@ KgDeclarativeView::KgDeclarativeView(QWidget *parent)
 }
 
 KgDeclarativeView::~KgDeclarativeView() = default;
+
+#endif
